@@ -3,11 +3,11 @@
 ;; Author:       Mats Lidell <matsl@gnu.org>
 ;;
 ;; Orig-Date:    28-Feb-21 at 22:52:00
-;; Last-Mod:      8-Mar-24 at 16:52:52 by Mats Lidell
+;; Last-Mod:     23-Nov-25 at 12:59:17 by Bob Weiner
 ;;
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
-;; Copyright (C) 2021-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2021-2025  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -20,9 +20,9 @@
 ;;; Code:
 
 (require 'ert)
+(require 'ert-x)
 (require 'hbut)
 (require 'el-mock)
-(require 'with-simulated-input)
 (require 'hy-test-helpers "test/hy-test-helpers")
 
 (ert-deftest hbut-defal ()
@@ -63,7 +63,6 @@
     (ibtype:delete 'ibtypes::defal-url)))
 
 (ert-deftest hbut-defal-key-sequence ()
-  (skip-unless (not noninteractive))
   (defal defal-key "{C-h v \\1 RET}")
   (unwind-protect
       (with-temp-buffer
@@ -112,7 +111,7 @@
           (insert "<<<DEMO>>>")
           (goto-char 4)
           (action-key)
-          (should (string= (expand-file-name "DEMO" hyperb:dir) buffer-file-name)))
+          (should (string= (expand-file-name "DEMO" hyperb:dir) (hypb:buffer-file-name))))
       (hy-test-helpers:kill-buffer "DEMO")
       (ibtype:delete 'ibtypes::defil-path-it))))
 
@@ -137,7 +136,6 @@
     (ibtype:delete 'ibtypes::defil-url)))
 
 (ert-deftest hbut-defil-key-sequence ()
-  (skip-unless (not noninteractive))
   (defil defil-key "<<<" ">>>" ".*" "{C-h v \\& RET}")
   (unwind-protect
       (with-temp-buffer
@@ -149,6 +147,18 @@
         (should (looking-at "emacs-version")))
     (ibtype:delete 'ibtypes::defil-key)))
 
+(ert-deftest hbut-defil-verbatim ()
+  "Verify defil to recognize filenames highlighted using org =verbatim= text."
+  ;; gh#rswgnu/hyperbole/503
+  (defil defil-verbatim "=" "=" ".*" "\\&")
+  (unwind-protect
+      (with-temp-buffer
+        (org-mode)
+        (insert "=~/test.txt=\n")
+        (goto-char 4)
+        (hy-test-helpers:action-key-should-call-hpath:find "~/test.txt"))
+    (ibtype:delete 'ibtypes::defil-verbatim)))
+
 ;; Labels
 (ert-deftest hbut-ib-link-to-file-with-label ()
   (with-temp-buffer
@@ -170,14 +180,15 @@
     (insert "<[PR34]>: \"https://github.com/rswgnu/hyperbole/pull/34\"")
     (goto-char 4)
     (let ((browse-url-browser-function 'hbut-defal-url))
-      (action-key))))
+      (action-key))
+    (should (hattr:ibtype-is-p 'www-url))))
 
 (ert-deftest hbut-ib-create-label ()
   "Create a label for an implicit button."
   (with-temp-buffer
     (insert "\"/tmp\"\n")
     (goto-char 3)
-    (with-simulated-input "TMP RET"
+    (hy-test-helpers:ert-simulate-keys "TMP\r"
       (let ((enable-recursive-minibuffers t))
 	(hui:ibut-label-create)
 	(should (string= "<[TMP]> - \"/tmp\"\n" (buffer-string)))))))
@@ -187,7 +198,7 @@
   (with-temp-buffer
     (insert "<[LBL]>: \"/tmp\"\n")
     (goto-char 14)
-    (with-simulated-input "TMP RET"
+    (hy-test-helpers:ert-simulate-keys "TMP\r"
       (condition-case err
           (hui:ibut-label-create)
         (error
@@ -230,8 +241,10 @@
       (with-temp-buffer
         (insert "receiver@mail.org")
         (goto-char 2)
-        (action-key)
-        (should (string= "*mail*" (buffer-name))))
+        (let ((mail-user-agent 'sendmail-user-agent))
+          (action-key))
+	(should (hattr:ibtype-is-p 'mail-address))
+        (should (string-match "mail\\*" (buffer-name))))
     (hy-test-helpers:kill-buffer "*mail*")))
 
 ;; Path name
@@ -242,6 +255,7 @@
         (goto-char 2)
 	(let ((enable-local-variables nil))
           (action-key))
+	(should (hattr:ibtype-is-p 'pathname))
         (should (string= "DEMO" (buffer-name))))
     (hy-test-helpers:kill-buffer "DEMO")))
 
@@ -252,6 +266,7 @@
         (goto-char 2)
 	(let ((enable-local-variables nil))
           (action-key))
+	(should (hattr:ibtype-is-p 'pathname))
         (should (string= "DEMO" (buffer-name))))
     (hy-test-helpers:kill-buffer "DEMO")))
 
@@ -260,6 +275,7 @@
     (insert "\"${HOME}\"")
     (goto-char 2)
     (action-key)
+    (should (hattr:ibtype-is-p 'pathname))
     (should (equal major-mode 'dired-mode))
     (should (equal (expand-file-name default-directory)
 		   (file-name-as-directory (getenv "HOME"))))))
@@ -270,8 +286,9 @@
         (insert "\"hyperbole.el\"")
         (goto-char 2)
         (action-key)
+	(should (hattr:ibtype-is-p 'pathname))
         (should (equal major-mode 'emacs-lisp-mode))
-        (should (buffer-file-name))
+        (should (hypb:buffer-file-name))
         (should (string= "hyperbole.el" (buffer-name))))
     (hy-test-helpers:kill-buffer "hyperbole.el")))
 
@@ -284,7 +301,8 @@
           (insert (concat "\"" file ":1\""))
           (goto-char 2)
           (action-key)
-          (should (string= file (buffer-file-name)))
+	  (should (hattr:ibtype-is-p 'pathname-line-and-column))
+          (should (string= file (hypb:buffer-file-name)))
           (should (looking-at "Line1")))
       (hy-delete-file-and-buffer file))))
 
@@ -303,7 +321,8 @@
           (should (looking-at-p (concat "\"" file ":2\"")))
           (forward-char 2)
           (action-key)
-          (should (string= file (buffer-file-name)))
+	  (should (hattr:ibtype-is-p 'pathname-line-and-column))
+          (should (string= file (hypb:buffer-file-name)))
           (should (looking-at "Line2")))
       (hy-delete-file-and-buffer file)
       (hy-delete-file-and-buffer ibutfile))))
@@ -317,10 +336,37 @@
           (insert (concat "\"" file "#Anchor\""))
           (goto-char 2)
           (action-key)
-          (should (string= file (buffer-file-name)))
+	  (should (hattr:ibtype-is-p 'pathname))
+          (should (string= file (hypb:buffer-file-name)))
           (should (looking-at "\* Anchor")))
       (hy-delete-file-and-buffer file))))
 
+(ert-deftest hbut-pathname-html-anchor-test ()
+  "Pathname with HTML anchor."
+  (let ((file (make-temp-file "hypb" nil ".html" "\
+<a href=\"#idstr1\">link</a>
+<h2 id=\"idstr11\"> header</h2>
+<h2 id=\"idstr1\"> header</h2>
+<h2 id=\"idstr22\"> header</h2>
+<h2 id=\"idstr2\"> header</h2>
+")))
+    (unwind-protect
+        (progn
+          ;; Link to same file
+          (with-current-buffer (find-file file)
+            (goto-char 12)
+            (action-key)
+            (should (hattr:ibtype-is-p 'pathname))
+            (should (looking-at "id=\"idstr1\"")))
+          ;; Link from temp buff to file
+          (with-temp-buffer
+            (insert (format "<a href=\"%s#idstr2\">link</a>\n" file))
+            (goto-char 12)
+            (action-key)
+            (should (hattr:ibtype-is-p 'pathname))
+            (should (looking-at "id=\"idstr2\""))))
+      (hy-delete-file-and-buffer file))))
+
 (ert-deftest hbut-pathname-anchor-trailing-text ()
   "Pathname with anchor and trailing parenthesised text."
   (let ((file (make-temp-file "hypb" nil nil
@@ -330,7 +376,8 @@
         (insert (concat "\"" file "#Anchor Plus\""))
         (goto-char 2)
         (action-key)
-        (should (string= file (buffer-file-name)))
+	(should (hattr:ibtype-is-p 'pathname))
+        (should (string= file (hypb:buffer-file-name)))
         (should (looking-at "\* Anchor Plus \(Parenthesised text follows\)")))
     (hy-delete-file-and-buffer file))))
 
@@ -359,7 +406,8 @@
         (insert (concat "\"" file "#Anchor:2\""))
         (goto-char 2)
         (action-key)
-        (should (string= file (buffer-file-name)))
+	(should (hattr:ibtype-is-p 'pathname-line-and-column))
+        (should (string= file (hypb:buffer-file-name)))
         (should (looking-at "Next Line")))
     (hy-delete-file-and-buffer file))))
 
@@ -372,7 +420,8 @@
           (insert (concat "\"" file "#Anchor:2:5\""))
           (goto-char 2)
           (action-key)
-          (should (string= file (buffer-file-name)))
+	  (should (hattr:ibtype-is-p 'pathname-line-and-column))
+          (should (string= file (hypb:buffer-file-name)))
           (should (= (line-number-at-pos) 3))
           (should (= (current-column) 5))
           (should (looking-at "Line")))
@@ -385,6 +434,7 @@
         (insert "\"${load-path}/hypb.el:11:5\"")
         (goto-char 2)
         (action-key)
+	(should (hattr:ibtype-is-p 'pathname-line-and-column))
         (should (string= "hypb.el" (buffer-name)))
         (should (= (line-number-at-pos) 11))
         (should (= (current-column) 5)))
@@ -395,9 +445,11 @@
   (with-temp-buffer
     (insert "\"-${hyperb:dir}/test/hy-test-dependencies.el\"")
     (goto-char 2)
-    (action-key)
-    (hy-test-helpers:should-last-message "Loading")
-    (hy-test-helpers:should-last-message "hy-test-dependencies.el")))
+    (ert-with-message-capture cap
+      (action-key)
+      (should (hattr:ibtype-is-p 'pathname))
+      (hy-test-helpers:should-last-message "Loading" cap)
+      (hy-test-helpers:should-last-message "hy-test-dependencies.el" cap))))
 
 (ert-deftest hbut-pathname-directory-test ()
   "Pathname with directory opens Dired."
@@ -406,6 +458,7 @@
         (insert "\"/tmp\"")
         (goto-char 2)
         (action-key)
+	(should (hattr:ibtype-is-p 'pathname))
         (should (string-equal default-directory "/tmp/"))
         (should (eq major-mode 'dired-mode)))
     (hy-test-helpers:kill-buffer "tmp")))
@@ -421,6 +474,7 @@
           (action-key)
         (error
          (progn
+	   (should-not (hattr:ibtype-is-p 'pathname))
            (should (equal (car err) 'error))
            (should (string-match
                     "(Hyperbole Action Key): No action defined for this context; try another location"
@@ -428,35 +482,33 @@
 
 ;; ctags
 ; Seems ctags -v does not give the proper answer
-;; FIXME: Rewrite to not depend on hy-test-helpers.el
 (ert-deftest hbut-ctags-vgrind-test ()
   (unwind-protect
       (with-temp-buffer
-        (insert "hy-test-helpers:consume-input-events hy-test-helpers.el 25\n")
+        (insert "test-func test-data.el 19\n")
         (goto-char (point-min))
         (forward-char 4)
-        (let ((default-directory (expand-file-name "test" hyperb:dir)))
+        (let ((default-directory (ert-resource-directory)))
           (action-key)
-          (should (looking-at "(defun hy-test-helpers:consume-input-events"))))
-    (hy-test-helpers:kill-buffer "hy-test-helpers.el")))
+	  (should (hattr:ibtype-is-p 'ctags))
+          (should (looking-at "(defun test-func"))))
+    (hy-test-helpers:kill-buffer "test-data.el")))
 
 ;; etags
-;; FIXME: Rewrite to not depend on hy-test-helpers.el
 (ert-deftest hbut-etags-test ()
-  (unwind-protect
-      (with-temp-buffer
-        (insert "\n")
-        (insert "hy-test-helpers.el,237\n")
-        (insert "(defun hy-test-helpers:consume-input-events 25,518\n")
-        (rename-buffer (concat "TAGS" (buffer-name)))
-        (goto-char (point-min))
-        (forward-line 2)
-        (forward-char 10)
-        (let ((default-directory (expand-file-name "test" hyperb:dir)))
-          (action-key)
-          (set-buffer "hy-test-helpers.el")
-          (should (looking-at "(defun hy-test-helpers:consume-input-events"))))
-    (hy-test-helpers:kill-buffer "hy-test-helpers.el")))
+  (let ((tags (find-file (ert-resource-file "TAGS"))))
+    (unwind-protect
+        (with-current-buffer tags
+          (goto-char (point-min))
+          (forward-line 2)
+          (forward-char 10)
+          (let ((default-directory (ert-resource-directory)))
+            (action-key)
+	    (should (hattr:ibtype-is-p 'etags))
+            (set-buffer "test-data.el")
+            (should (looking-at "(defun test-func"))))
+      (hy-test-helpers:kill-buffer "test-data.el")
+      (hy-test-helpers:kill-buffer tags))))
 
 ;; text-toc
 (ert-deftest hbut-text-toc-test ()
@@ -466,6 +518,7 @@
         (goto-char (point-min))
         (re-search-forward "^[ \t]*\\* Koutl")
         (action-key)
+	(should (hattr:ibtype-is-p 'text-toc))
         (should (bolp))
         (should (looking-at "^[ \t]*\\* Koutliner")))
     (hy-test-helpers:kill-buffer "DEMO")))
@@ -480,6 +533,7 @@
         (forward-char -2)
         (let ((hpath:display-where 'this-window))
           (action-key)
+	  (should (hattr:ibtype-is-p 'dir-summary))
           (should (string= "HY-ABOUT" (buffer-name)))))
     (hy-test-helpers:kill-buffer "MANIFEST")
     (hy-test-helpers:kill-buffer "HY-ABOUT")))
@@ -492,16 +546,18 @@
       (goto-char 2)
       (with-mock
         (mock (actypes::link-to-rfc "822") => t)
-        (should (action-key))))))
+	(should (action-key))
+	(should (hattr:ibtype-is-p 'rfc))))))
 
 ;; man-apropos
 (ert-deftest hbut-man-apropos-test ()
   (with-temp-buffer
     (insert "rm (1)   - remove")
-    (goto-char 4)
+    (goto-char 2)
     (with-mock
      (mock (man "rm(1)") => t)
-     (action-key))))
+     (should (action-key))
+     (should (hattr:ibtype-is-p 'man-apropos)))))
 
 ;; info-node
 (ert-deftest hbut-info-node-test ()
@@ -511,6 +567,7 @@
         (insert "\"(emacs)Top\"")
         (goto-char 6)
         (action-key)
+	(should (hattr:ibtype-is-p 'Info-node))
         (should (string= "*info*" (buffer-name))))
     (hy-test-helpers:kill-buffer "*info*")))
 
@@ -520,6 +577,16 @@
   (with-temp-buffer
     (insert "\"!/bin/ls\"")
     (goto-char 2)
+    (let ((was-called nil))
+      (cl-letf (((symbol-function 'actypes::exec-shell-cmd)
+                 (lambda (filename)
+                   (setq was-called (should (string= "/bin/ls" filename))))))
+        (action-key)
+        (should was-called))))
+  ;; Whitespace before quote
+  (with-temp-buffer
+    (insert " \"!/bin/ls\"")
+    (goto-char 3)
     (let ((was-called nil))
       (cl-letf (((symbol-function 'actypes::exec-shell-cmd)
                  (lambda (filename)
@@ -533,6 +600,16 @@
   (with-temp-buffer
     (insert "\"&/bin/ls\"")
     (goto-char 2)
+    (let ((was-called nil))
+      (cl-letf (((symbol-function 'actypes::exec-window-cmd)
+                 (lambda (filename)
+                   (setq was-called (should (string= "/bin/ls" filename))))))
+        (action-key)
+        (should was-called))))
+  ;; Whitespace before quote
+  (with-temp-buffer
+    (insert " \"&/bin/ls\"")
+    (goto-char 3)
     (let ((was-called nil))
       (cl-letf (((symbol-function 'actypes::exec-window-cmd)
                  (lambda (filename)
@@ -553,7 +630,7 @@
         (should was-called)))))
 
 (ert-deftest hbut-load-modifier-with-plain-file-loads-file-from-load-path ()
-  "Path prefix - filename without directory will load from`load-path'."
+  "Path prefix - filename without directory will load from `load-path'."
   (setq features (delq 'tutorial features))
   (with-temp-buffer
     (insert "\"-tutorial.el\"")
@@ -571,9 +648,8 @@ Regression: Looked up path name '-narrow'."
           (goto-char (point-min))
           (goto-char (1- (re-search-forward "-")))
           (should (string= (smart-lisp-at-tag-p) symbol-name))
-          (with-mock
-            (mock (smart-lisp-find-tag nil nil) => t)
-            (action-key)))
+          (action-key)
+	  (should (looking-at "(defun hmail:msg-narrow (")))
       (hy-delete-file-and-buffer el-file))))
 
 (ert-deftest hmouse-drv--hmouse-choose-link-and-referent-windows--two-windows-same-frame ()
@@ -623,10 +699,59 @@ The frame setup is mocked."
       (hy-delete-file-and-buffer filea)
       (hy-delete-file-and-buffer fileb))))
 
-;; This file can't be byte-compiled without the `el-mock' and
-;; `with-simulated-input' package (because of the use of the
-;; `with-mock' and `with-simulated-input' macro), which is not a
-;; dependency of Hyperbole.
+(ert-deftest hmouse-drv--hkey-actions ()
+  "Verify `hkey-actions'."
+  ;; No action
+  (let ((hkey-alist '((nil . ((action) . (assist))))))
+    (should-not (hkey-actions)))
+
+  (let ((hkey-alist '((t . ((action) . (assist))))))
+    ;; Normal case
+    (should (equal (hkey-actions) '((action) assist)))
+
+    ;; Point is moved by predicate
+    (let ((marker 1))
+      (cl-letf (((symbol-function 'point-marker)
+                 (lambda () (setq marker (1+ marker)))))
+        (let ((err (should-error (hkey-actions) :type 'error)))
+          (should (string-match-p
+                   (format "(Hyperbole): predicate %s improperly moved point from %s to %s" t 2 4)
+                   (cadr err))))))
+
+    ;; Debug is called for action and assist.
+    (let ((hkey-debug t))
+      (dolist (v '(nil t))
+        (let ((assist-flag v))
+          (mocklet (((hkey-debug t t (if assist-flag '(assist) '(action))) => t))
+            (should (equal (hkey-actions) '((action) assist)))))))))
+
+(defvar hmouse-drv--hkey-execute-called nil "For checking what method was called.")
+(defun hmouse-drv--hkey-execute-action () "Action." (setq hmouse-drv--hkey-execute-called "action"))
+(defun hmouse-drv--hkey-execute-assist () "Assist." (setq hmouse-drv--hkey-execute-called "assist"))
+
+(ert-deftest hmouse-drv--hkey-execute ()
+  "Verify `hkey-execute'."
+  ;; No action
+  (let ((hkey-alist '((nil . ("action" . "assist")))))
+    (should-not (hkey-execute nil)))
+
+  ;; Normal case with action or assist
+  (let ((hkey-alist '((t . ((hmouse-drv--hkey-execute-action) . (hmouse-drv--hkey-execute-assist)))))
+        hmouse-drv--hkey-execute-called)
+    ;; Action
+    (should (equal (hkey-execute nil) '(hmouse-drv--hkey-execute-action)))
+    (should (string= hmouse-drv--hkey-execute-called "action"))
+    ;; Assist
+    (should (equal (hkey-execute t) '(hmouse-drv--hkey-execute-assist)))
+    (should (string= hmouse-drv--hkey-execute-called "assist"))
+
+    ;; Print debug info
+    (let ((hkey-debug t))
+      (mocklet (((hypb:eval-debug *) => t))
+        (should (equal (hkey-execute nil) '(hmouse-drv--hkey-execute-action)))))))
+
+;; This file can't be byte-compiled without the `el-mock' package
+;; which is not a dependency of Hyperbole.
 ;;  Local Variables:
 ;;  no-byte-compile: t
 ;;  End:
